# artifact-hub

Manage artifacts using object storage


## prerequisite

create an `.env` file by using the `.example.env` template/sample and fill in the right details


## Run tests

```shell
pytest
```

